pub fn init(config: TelemetryConfig) -> boolExpand description
Install the global tracing subscriber.
Returns false if a subscriber was already installed — which happens in test
binaries and is harmless, so this never panics.
pub fn init(config: TelemetryConfig) -> boolInstall the global tracing subscriber.
Returns false if a subscriber was already installed — which happens in test
binaries and is harmless, so this never panics.